@@ -36,7 +36,7 @@ Enter 'Yes' to continue this deployment scripts."
   done
   fi
 }
-  
+
 function prepare_installer(){
 #########################
 # Function: prepare_installer
@@ -46,18 +46,18 @@ function prepare_installer(){
 
   reset_function_timer
   cd $SCRIPTPATH
-  
+
   beginLogging "Start Preparing installer machine with necessary tools."
 
 ##   # Prepare local yum repo
 ##   if [[ ! -f /etc/yum.repos.d/cms_repo.repo ]]; then
 ##     check_packages "$CMS_RPM_PACKAGE"
-##   
+##
 ##     #if [[  $(yum version > /dev/null 2>&1; echo $?) -ne 0 ]]; then
 ##     #  echo "[INFO] Installing yum-util."
 ##     #  sudo rpm -Uvh $RPMFOLDER/yum-utils-*.rpm
 ##     #fi
-##       
+##
 ##     if [[  $(httpd -v > /dev/null 2>&1; echo $?) -ne 0 ]]; then
 ##       echo "[INFO] Installing httpd."
 ##       sudo rpm -Uvh $RPMFOLDER/httpd/*.rpm
@@ -65,10 +65,10 @@ function prepare_installer(){
 ##     sudo sed -i 's/^Listen .*/Listen 8181/' /etc/httpd/conf/httpd.conf
 ##     sudo systemctl restart httpd
 ##     sudo systemctl enable httpd
-##   
+##
 ##     sudo mkdir -p /var/www/cms_repo
 ##     sudo tar -xzf $SCRIPTPATH/packages/$CMS_RPM_PACKAGE -C /var/www/cms_repo
-##   
+##
 ##     sudo tee -a /etc/yum.repos.d/cms_repo.repo << EOM
 ## [cms_repo]
 ## baseurl = http://127.0.0.1:8181/cms_repo
@@ -77,7 +77,7 @@ function prepare_installer(){
 ## name = CMS Yum repository
 ## proxy = _none_
 ## EOM
-##   
+##
 ##   fi
 
   check_packages "$CMS_RPM_PACKAGE"
@@ -189,15 +189,19 @@ function prepare_installer(){
       fi
     fi
     if [[ $kc_install == "true" ]]; then
-      kc_package=$(ls $RPMFOLDER/kubectl/kubectl-${kc_major_deserve}.${kc_minor_deserve}.*.x86_64.rpm|sort -V|tail -n 1)
-      echo "[INFO] Installing kubectl ${kc_major_deserve}.${kc_minor_deserve}"
-      sudo rpm -Uv $kc_package
-    else
-      echo "[INFO] Current kubectl client info: $kc_version_current"
+      if [[ $kc_minor -ge 27 ]] ; then
+        echo "[INFO] Installing kubectl ${kc_major_deserve}.${kc_minor_deserve}"
+        kc_package=$(ls $RPMFOLDER/kubectl/kubectl-${kc_major_deserve}.${kc_minor_deserve}.*)
+        chmod +x $kc_package
+        sudo cp $kc_package /usr/bin/kubectl
+      else
+        kc_package=$(ls $RPMFOLDER/kubectl/kubectl-${kc_major_deserve}.${kc_minor_deserve}.*.x86_64.rpm|sort -V|tail -n 1)
+        echo "[INFO] Installing kubectl ${kc_major_deserve}.${kc_minor_deserve}"
+        sudo rpm -Uv $kc_package
+      fi
     fi
   fi
   # End Prepare kubectl
-
   # Prepare terraform
   #if [[  $(terraform -v > /dev/null 2>&1; echo $?) -ne 0 ]] && [[ -n $CLOUDPLATFORM ]]; then
   # Ensure to install the terraform with expected version
@@ -243,7 +247,7 @@ function prepare_installer(){
     #sudo yum install -y google-cloud-sdk
     sudo rpm -Uvh $RPMFOLDER/google-cloud-sdk/google-cloud-sdk-321.0.0-1.x86_64.rpm
     gcloud init --skip-diagnostics
-# Note: Follow below instruction to finish the authantication 
+# Note: Follow below instruction to finish the authantication
 #You must log in to continue. Would you like to log in (Y/n)?  y
 #Go to the following link in your browser:
 #    https://accounts.google.com/o/oauth2/auth?response_type=code&client_id=32555940559.apps.googleusercontent.com&redirect_uri=urn%3Aietf%3Awg%3Aoauth%3A2.0%3Aoob&scope=openid+https%3A%2F%2Fwww.googleapis.com%2Fauth%2Fuserinfo.email+https%3A%2F%2Fwww.googleapis.com%2Fauth%2Fcloud-platform+https%3A%2F%2Fwww.googleapis.com%2Fauth%2Fappengine.admin+https%3A%2F%2Fwww.googleapis.com%2Fauth%2Fcompute+https%3A%2F%2Fwww.googleapis.com%2Fauth%2Faccounts.reauth&state=3lUv3sglggeS5WdEQgTn16h9qMrciD&code_challenge=TI4360zLEmL0E-1Br1Lsf8DeWzPAfU3t42XKcrzKDEk&prompt=consent&code_challenge_method=S256&access_type=offline
@@ -291,7 +295,7 @@ EOM
 
   #[TODO]
   # update kubenetes manifest configuraion files with necessary modifications.
-  
+
   # Prepare openssl
   if ! openssl version &>/dev/null; then
     echo "[INFO] Installing openssl ..."
@@ -311,11 +315,10 @@ EOM
        [ -d /usr/java/openjdk8 ] || sudo mkdir -p /usr/java/openjdk8
        sudo tar zxf $RPMFOLDER/openjdk-keytool/OpenJDK8U-jdk_x64_linux_hotspot_8u262b10.tar.gz -C /usr/java/openjdk8
        if [[ $? -eq 0 ]]; then
-	  sudo ln -s /usr/java/openjdk8/jdk8u262-b10/bin/keytool /bin/keytool
+          sudo ln -s /usr/java/openjdk8/jdk8u262-b10/bin/keytool /bin/keytool
        fi
     fi
   fi
   # End Prepare openjdk:keytool
   running_time
-
 }
